@@ -1,5 +1,5 @@
 # Tests the KmeansParam class.
-# library(bluster); library(testthat); source('test-hclust-param.R')
+# library(bluster); library(testthat); source('test-kmeans-param.R')
 
 test_that("KmeansParam constructor and utilities work correctly", {
     X <- KmeansParam(centers=10)
@@ -12,11 +12,12 @@ test_that("KmeansParam constructor and utilities work correctly", {
 
     X <- KmeansParam(centers=log)
     expect_true(is.function(X[["centers"]]))
+    expect_identical(centers(X, 20), as.integer(round(log(20))))
 
     X <- KmeansParam(centers=10, algorithm="Lloyd")
     expect_identical(X[["algorithm"]], "Lloyd")
-    X[["algorithm"]] <- NULL
-    expect_identical(X[["algorithm"]], NULL)
+    X[["algorithm"]] <- "Hartigan"
+    expect_identical(X[["algorithm"]], "Hartigan")
 })
 
 test_that("KmeansParam validity works correctly", {
@@ -38,5 +39,12 @@ test_that("clusterRows works correctly", {
     set.seed(9999)
     full <- clusterRows(m, KmeansParam(sqrt), full=TRUE)
     expect_identical(out, full$cluster)
-    expect_s3_class(full$objects, "kmeans")
+    expect_s3_class(full$objects$kmeans, "kmeans")
+
+    # Responds to the options.
+    set.seed(100000)
+    suppressWarnings(ref <- kmeans(m, centers=20, nstart=5, iter.max=3, algorithm="Lloyd")$cluster)
+    set.seed(100000)
+    suppressWarnings(out <- clusterRows(m, KmeansParam(centers=20, nstart=5, iter.max=3, algorithm="Lloyd")))
+    expect_identical(factor(ref), out)
 })
